==> ZenTaoPMS.15.2.zip: zentaopms/module/project/lang/vi.php <==
<?php
/* Actions. */
$lang->project->createGuide       = 'Select Template';
$lang->project->index             = 'Dashboard';
$lang->project->home              = 'Home';
$lang->project->create            = 'Create Project';
$lang->project->edit              = 'Edit';
$lang->project->batchEdit         = 'Batch Edit Projects';
$lang->project->view              = 'Project View';
$lang->project->batchEdit         = 'Batch Edit';
$lang->project->browse            = 'Projects';
$lang->project->all               = 'All';
$lang->project->start             = 'Start';
$lang->project->finish            = 'Finish';
$lang->project->suspend           = 'Suspend';
$lang->project->delete            = 'Delete';
$lang->project->close             = 'Close';
$lang->project->activate          = 'Activate';
$lang->project->group             = 'Privilege Group';
$lang->project->createGroup       = 'Create Group';
$lang->project->editGroup         = 'Edit Group';
$lang->project->copyGroup         = 'Copy Group';
$lang->project->manageView        = 'Manage View';
$lang->project->managePriv        = 'Manage Privilege';
$lang->project->manageMembers     = 'Manage Team';
$lang->project->export            = 'Export';
$lang->project->addProduct        = 'Add Product';
$lang->project->manageGroupMember = 'Manage Group';
$lang->project->moduleSetting     = 'List Settings';
$lang->project->moduleOpen        = 'Program Name';
$lang->project->dynamic           = 'Dynamic';
$lang->project->execution         = 'Execution';
$lang->project->qa                = 'QA';
$lang->project->bug               = 'Bug List';
$lang->project->testcase          = 'Case List';
$lang->project->testtask          = 'Test Task';
$lang->project->build             = 'Build';
$lang->project->updateOrder       = 'Order';
$lang->project->sort              = 'Order';
$lang->project->whitelist         = 'Project Whitelist';
$lang->project->addWhitelist      = 'Project Add Whitelist';
$lang->project->unbindWhitelist   = 'Project Remove Whitelist';
$lang->project->manageProducts    = 'Manage Products';
$lang->project->copyTitle         = 'Please select an project to copy';
$lang->project->errorSameProducts = 'Project cannot be associated with multiple identical products.';
$lang->project->errorNoProducts   = 'At least one product is associated';
$lang->project->copyNoProject     = 'There are no items available to copy.';
$lang->project->searchByName      = 'Enter the project name to retrieve';
$lang->project->linkedProducts    = "Linked {$lang->productCommon}s";
$lang->project->unlinkedProducts  = "Unlinked {$lang->productCommon}s";

/* Fields. */
$lang->project->common             = 'Project';
$lang->project->stage              = 'Stage';
$lang->project->PM                 = 'Manager';
$lang->project->name               = 'Name';
$lang->project->category           = 'Category';
$lang->project->desc               = 'Description';
$lang->project->code               = 'Code';
$lang->project->copy               = 'Copy';
$lang->project->begin              = 'Begin';
$lang->project->end                = 'End';
$lang->project->status             = 'Status';
$lang->project->PM                 = 'Manager';
$lang->project->budget             = 'Budget';
$lang->project->template           = 'Template';
$lang->project->estimate           = 'Estimates';
$lang->project->consume            = 'Cost';
$lang->project->surplus            = 'Left';
$lang->project->progress           = 'Progress';
$lang->project->dateRange          = 'Duration';
$lang->project->to                 = ' to ';
$lang->project->realEnd            = 'Actual End';
$lang->project->realBegan          = 'Actual Began';
$lang->project->bygrid             = 'Kanban';
$lang->project->bylist             = 'List';
$lang->project->mine               = 'My';
$lang->project->myProject          = 'Mine';
$lang->project->other              = 'Others';
$lang->project->acl                = 'Access control';
$lang->project->setPlanduration    = 'Set Duration';
$lang->project->auth               = 'Access Control';
$lang->project->durationEstimation = 'Estimated Workload';
$lang->project->teamCount          = 'Man';
$lang->project->leftStories        = 'Left Stories';
$lang->project->leftTasks          = 'Left Tasks';
$lang->project->leftBugs           = 'Left Bugs';
$lang->project->children           = 'Child Project';
$lang->project->parent             = 'Parent Project';
$lang->project->allStories         = 'All Stories';
$lang->project->doneStories        = 'Finished Stories';
$lang->project->doneProjects       = 'Finished';
$lang->project->allInput           = 'Total Input';
$lang->project->weekly             = 'Program Weekly';
$lang->project->pv                 = 'PV';
$lang->project->ev                 = 'EV';
$lang->project->sv                 = 'SV%';
$lang->project->ac                 = 'AC';
$lang->project->cv                 = 'CV%';
$lang->project->teamCount          = 'Team';
$lang->project->longTime           = 'Long-Term Program';
$lang->project->future             = 'TBD';
$lang->project->moreProject        = 'More Project';
$lang->project->days               = 'Available Days';

$lang->project->productNotEmpty        = 'Please link products or create products.';
$lang->project->existProductName       = 'Product name already exists.';
$lang->project->changeProgram          = '%s > Change project';
$lang->project->changeProgramTip       = 'After modifying the project set, the products linked with the project will also modify the project set to which it belongs. Please confirm whether to modify it.';
$lang->project->linkedProjectsTip      = 'Linked projects are as follows';
$lang->project->multiLinkedProductsTip = 'The following products linked to this project are also linked to other projects, please unlink before proceeding.';
$lang->project->linkStoryByPlanTips    = "This action will associate all {$lang->SRCommon} under the selected plan to this project";
$lang->project->createExecution        = "There is no {$lang->executionCommon} under this project, please create {$lang->executionCommon} first";

$lang->project->tenThousand = '';

$lang->project->unitList['CNY'] = 'RMB';
$lang->project->unitList['USD'] = 'USD';
$lang->project->unitList['HKD'] = 'HKD';
$lang->project->unitList['NTD'] = 'New Taiwan';
$lang->project->unitList['EUR'] = 'Euro';
$lang->project->unitList['DEM'] = 'Deutsche Mark';
$lang->project->unitList['CHF'] = 'Swiss Franc';
$lang->project->unitList['FRF'] = 'French Franc';
$lang->project->unitList['GBP'] = 'Pound';
$lang->project->unitList['NLG'] = 'Florin';
$lang->project->unitList['CAD'] = 'Canadian';
$lang->project->unitList['RUR'] = 'Russian Ruble';
$lang->project->unitList['INR'] = 'Indian';
$lang->project->unitList['AUD'] = 'Australian';
$lang->project->unitList['NZD'] = 'New Zealand';
$lang->project->unitList['THB'] = 'Thai Baht';
$lang->project->unitList['SGD'] = 'Singapore';

$lang->project->currencySymbol['CNY'] = '¥';
$lang->project->currencySymbol['USD'] = '$';
$lang->project->currencySymbol['HKD'] = 'HK$';
$lang->project->currencySymbol['NTD'] = 'NT$';
$lang->project->currencySymbol['EUR'] = '€';
$lang->project->currencySymbol['DEM'] = 'DEM';
$lang->project->currencySymbol['CHF'] = '₣';
$lang->project->currencySymbol['FRF'] = '₣';
$lang->project->currencySymbol['GBP'] = '£';
$lang->project->currencySymbol['NLG'] = 'ƒ';
$lang->project->currencySymbol['CAD'] = '$';
$lang->project->currencySymbol['RUR'] = '₽';
$lang->project->currencySymbol['INR'] = '₹';
$lang->project->currencySymbol['AUD'] = 'A$';
$lang->project->currencySymbol['NZD'] = 'NZ$';
$lang->project->currencySymbol['THB'] = '฿';
$lang->project->currencySymbol['SGD'] = 'S$';

$lang->project->modelList['scrum']     = "Scrum";
$lang->project->modelList['waterfall'] = "CMMI";

$lang->project->featureBar['all']       = 'All';
$lang->project->featureBar['doing']     = 'Going';
$lang->project->featureBar['wait']      = 'Waiting';
$lang->project->featureBar['suspended'] = 'Suspended';
$lang->project->featureBar['closed']    = 'Closed';

$lang->project->aclList['private'] = 'Private (For team members and stakeholders only)';
$lang->project->aclList['open']    = "Open (accessible with project view permissions)";

$lang->project->acls['private'] = 'Private';
$lang->project->acls['open']    = "Open";

$lang->project->subAclList['private'] = "Private (Only the project leader, team members and stakeholders can access)";
$lang->project->subAclList['open']    = "Open (accessible with project view permissions)";
$lang->project->subAclList['program'] = 'Open in the program (all upper-level program team leaders and stakeholders, the project leader, team members and stakeholders can access)';

$lang->project->authList['extend'] = 'Inherit (system privilege and project privilege)';
$lang->project->authList['reset']  = 'Reset (project privilege only)';

$lang->project->statusList['wait']      = 'Waiting';
$lang->project->statusList['doing']     = 'Doing';
$lang->project->statusList['suspended'] = 'Suspended';
$lang->project->statusList['closed']    = 'Closed';

$lang->project->endList[31]  = 'One month';
$lang->project->endList[93]  = 'Trimester';
$lang->project->endList[186] = 'Half yearly';
$lang->project->endList[365] = 'One year';
$lang->project->endList[999] = 'Longtime';

$lang->project->empty                  = 'No project.';
$lang->project->accessDenied           = 'Access denied!';
$lang->project->chooseProgramType      = 'Select the project management model';
$lang->project->nextStep               = 'Next step';
$lang->project->hoursUnit              = '%s hours';
$lang->project->membersUnit            = '%s men';
$lang->project->lastIteration          = "Recent {$lang->executionCommon}";
$lang->project->ongoingStage           = 'Ongoing stage';
$lang->project->scrum                  = 'Scrum';
$lang->project->waterfall              = 'CMMI';
$lang->project->waterfallTitle         = 'CMMI';
$lang->project->cannotCreateChild      = 'It is not empty, so you cannot add a child. You can add a parent for it, and then create a child.';
$lang->project->confirmDelete          = "Do you want to delete [%s]?";
$lang->project->emptyPM                = 'No manager';
$lang->project->cannotChangeToCat      = "It is not empty, so you cannot change it to a parent.";
$lang->project->cannotCancelCat        = "It has child projects, so you cannot unmark the parent.";
$lang->project->parentBeginEnd         = "Parent begin&end date: %s ~ %s";
$lang->project->childLongTime          = "If a child as long-term projects, the parent should be long-term too.";
$lang->project->readjustTime           = 'Change the project begin&end date.';
$lang->project->notAllowRemoveProducts = 'The story of this product is linked with the project. Unlink it before doing any action.';

$lang->project->programTitle['0']    = 'Hide';
$lang->project->programTitle['base'] = 'Base-level project only';
$lang->project->programTitle['end']  = 'End-level project only';

$lang->project->accessDenied      = 'Access denied to this project';
$lang->project->chooseProgramType = 'Select management type';
$lang->project->scrumTitle        = 'Agile Development Management';
$lang->project->cannotCreateChild = 'The project has contents, so you cannot add a child project. You can create a parent project for this one and then add a child project for the parent project.';
$lang->project->hasChildren       = 'This project has a child project, so it cannot be deleted.';
$lang->project->confirmDelete     = 'Do you want to delete this project?';
$lang->project->cannotChangeToCat = "The project has contents, so you cannot it to a parent project.";
$lang->project->cannotCancelCat   = "There are child projects of this project. You cannot cancel the parent project mark.";
$lang->project->parentBeginEnd    = "The begin and end date of the parent project: %s ~ %s";
$lang->project->parentBudget      = "The budget of the parent project: ";
$lang->project->beginLetterParent = "The begin date of the parent project: %s. It cannot be < the begin date of its parent project.";
$lang->project->endGreaterParent  = "The end date of the parent project: %s. It cannot be > the end date of its parent project.";
$lang->project->beginGreateChild  = "The minimum start date of the project set: %s. The start date of the project cannot be less than the minimum start date of the project set.";
$lang->project->endLetterChild    = "The maximum finish date for the project set: %s. The completion date of a project cannot be greater than the maximum completion date of the project set.";
$lang->project->childLongTime     = "There are long-term projects in the child project, and the parent project should also be a long-term project.";

==> ZenTaoPMS.15.7.1.zip: zentaopms/module/project/lang/vi.php <==
<?php
/* Actions. */
$lang->project->createGuide       = 'Select Template';
$lang->project->index             = 'Dashboard';
$lang->project->home              = 'Home';
$lang->project->create            = 'Create Project';
$lang->project->edit              = 'Edit';
$lang->project->batchEdit         = 'Batch Edit Projects';
$lang->project->view              = 'Project View';
$lang->project->batchEdit         = 'Batch Edit';
$lang->project->browse            = 'Projects';
$lang->project->all               = 'All';
$lang->project->start             = 'Start';
$lang->project->finish            = 'Finish';
$lang->project->suspend           = 'Suspend';
$lang->project->delete            = 'Delete';
$lang->project->close             = 'Close';
$lang->project->activate          = 'Activate';
$lang->project->group             = 'Privilege Group';
$lang->project->createGroup       = 'Create Group';
$lang->project->editGroup         = 'Edit Group';
$lang->project->copyGroup         = 'Copy Group';
$lang->project->manageView        = 'Manage View';
$lang->project->managePriv        = 'Manage Privilege';
$lang->project->manageMembers     = 'Manage Team';
$lang->project->export            = 'Export';
$lang->project->addProduct        = 'Add Product';
$lang->project->manageGroupMember = 'Manage Group';
$lang->project->moduleSetting     = 'List Settings';
$lang->project->moduleOpen        = 'Program Name';
$lang->project->dynamic           = 'Dynamic';
$lang->project->execution         = 'Execution';
$lang->project->qa                = 'QA';
$lang->project->bug               = 'Bug List';
$lang->project->testcase          = 'Case List';
$lang->project->testtask          = 'Test Task';
$lang->project->build             = 'Build';
$lang->project->updateOrder       = 'Order';
$lang->project->sort              = 'Order';
$lang->project->whitelist         = 'Project Whitelist';
$lang->project->addWhitelist      = 'Project Add Whitelist';
$lang->project->unbindWhitelist   = 'Project Remove Whitelist';
$lang->project->manageProducts    = 'Manage Products';
$lang->project->copyTitle         = 'Please select an project to copy';
$lang->project->errorSameProducts = 'Project cannot be associated with multiple identical products.';
$lang->project->errorNoProducts   = 'At least one product is associated';
$lang->project->copyNoProject     = 'There are no items available to copy.';
$lang->project->searchByName      = 'Enter the project name to retrieve';
$lang->project->linkedProducts    = "Linked {$lang->productCommon}s";
$lang->project->unlinkedProducts  = "Unlinked {$lang->productCommon}s";
$lang->project->testreport        = 'Testreport';
$lang->project->selectProgram     = 'Program filtering';
$lang->project->teamMember        = 'Team Member';

/* Fields. */
$lang->project->common             = 'Project';
$lang->project->stage              = 'Stage';
$lang->project->PM                 = 'Manager';
$lang->project->name               = 'Name';
$lang->project->category           = 'Category';
$lang->project->desc               = 'Description';
$lang->project->code               = 'Code';
$lang->project->copy               = 'Copy';
$lang->project->begin              = 'Begin';
$lang->project->end                = 'End';
$lang->project->status             = 'Status';
$lang->project->PM                 = 'Manager';
$lang->project->budget             = 'Budget';
$lang->project->template           = 'Template';
$lang->project->estimate           = 'Estimates';
$lang->project->consume            = 'Cost';
$lang->project->surplus            = 'Left';
$lang->project->progress           = 'Progress';
$lang->project->dateRange          = 'Duration';
$lang->project->to                 = ' to ';
$lang->project->realEnd            = 'Actual End';
$lang->project->realBegan          = 'Actual Began';
$lang->project->bygrid             = 'Kanban';
$lang->project->bylist             = 'List';
$lang->project->bycard             = 'Card';
$lang->project->mine               = 'My';
$lang->project->myProject          = 'Mine';
$lang->project->other              = 'Others';
$lang->project->acl                = 'ACL';
$lang->project->setPlanduration    = 'Set Duration';
$lang->project->auth               = 'Privileges';
$lang->project->durationEstimation = 'Estimated Workload';
$lang->project->teamCount          = 'Man';
$lang->project->teamSumCount       = '%s people in total';
$lang->project->leftStories        = 'Left Stories';
$lang->project->leftTasks          = 'Left Tasks';
$lang->project->leftBugs           = 'Left Bugs';
$lang->project->leftHours          = 'Left Hours';
$lang->project->children           = 'Child Project';
$lang->project->parent             = 'Parent Project';
$lang->project->allStories         = 'All Stories';
$lang->project->doneStories        = 'Finished Stories';
$lang->project->doneProjects       = 'Finished';
$lang->project->allInput           = 'Total Input';
$lang->project->weekly             = 'Program Weekly';
$lang->project->pv                 = 'PV';
$lang->project->ev                 = 'EV';
$lang->project->sv                 = 'SV%';
$lang->project->ac                 = 'AC';
$lang->project->cv                 = 'CV%';
$lang->project->teamCount          = 'Team';
$lang->project->longTime           = 'Long-Term Program';
$lang->project->future             = 'TBD';
$lang->project->moreProject        = 'More Project';
$lang->project->days               = 'Available Days';

$lang->project->productNotEmpty        = 'Please link products or create products.';
$lang->project->existProductName       = 'Product name already exists.';
$lang->project->changeProgram          = '%s > Change project';
$lang->project->changeProgramTip       = 'After modifying the project set, the products linked with the project will also modify the project set to which it belongs. Please confirm whether to modify it.';
$lang->project->linkedProjectsTip      = 'Linked projects are as follows';
$lang->project->multiLinkedProductsTip = 'The following products linked to this project are also linked to other projects, please unlink before proceeding.';
$lang->project->linkStoryByPlanTips    = "This action will associate all {$lang->SRCommon} under the selected plan to this project";
$lang->project->createExecution        = "There is no {$lang->executionCommon} under this project, please create {$lang->executionCommon} first";

$lang->project->tenThousand = '';

$lang->project->unitList['CNY'] = 'RMB';
$lang->project->unitList['USD'] = 'USD';
$lang->project->unitList['HKD'] = 'HKD';
$lang->project->unitList['NTD'] = 'New Taiwan';
$lang->project->unitList['EUR'] = 'Euro';
$lang->project->unitList['DEM'] = 'Deutsche Mark';
$lang->project->unitList['CHF'] = 'Swiss Franc';
$lang->project->unitList['FRF'] = 'French Franc';
$lang->project->unitList['GBP'] = 'Pound';
$lang->project->unitList['NLG'] = 'Florin';
$lang->project->unitList['CAD'] = 'Canadian';
$lang->project->unitList['RUR'] = 'Russian Ruble';
$lang->project->unitList['INR'] = 'Indian';
$lang->project->unitList['AUD'] = 'Australian';
$lang->project->unitList['NZD'] = 'New Zealand';
$lang->project->unitList['THB'] = 'Thai Baht';
$lang->project->unitList['SGD'] = 'Singapore';

$lang->project->currencySymbol['CNY'] = '¥';
$lang->project->currencySymbol['USD'] = '$';
$lang->project->currencySymbol['HKD'] = 'HK$';
$lang->project->currencySymbol['NTD'] = 'NT$';
$lang->project->currencySymbol['EUR'] = '€';
$lang->project->currencySymbol['DEM'] = 'DEM';
$lang->project->currencySymbol['CHF'] = '₣';
$lang->project->currencySymbol['FRF'] = '₣';
$lang->project->currencySymbol['GBP'] = '£';
$lang->project->currencySymbol['NLG'] = 'ƒ';
$lang->project->currencySymbol['CAD'] = '$';
$lang->project->currencySymbol['RUR'] = '₽';
$lang->project->currencySymbol['INR'] = '₹';
$lang->project->currencySymbol['AUD'] = 'A$';
$lang->project->currencySymbol['NZD'] = 'NZ$';
$lang->project->currencySymbol['THB'] = '฿';
$lang->project->currencySymbol['SGD'] = 'S$';

$lang->project->modelList['scrum']     = "Scrum";
$lang->project->modelList['waterfall'] = "CMMI";

$lang->project->featureBar['all']       = 'All';
$lang->project->featureBar['doing']     = 'Going';
$lang->project->featureBar['wait']      = 'Waiting';
$lang->project->featureBar['suspended'] = 'Suspended';
$lang->project->featureBar['closed']    = 'Closed';

$lang->project->aclList['private'] = 'Private (For team members and stakeholders only)';
$lang->project->aclList['open']    = "Open (accessible with project view permissions)";

$lang->project->acls['private'] = 'Private';
$lang->project->acls['open']    = "Open";

$lang->project->subAclList['private'] = "Private (Only the project leader, team members and stakeholders can access)";
$lang->project->subAclList['open']    = "Open (accessible with project view permissions)";
$lang->project->subAclList['program'] = 'Open in the program (all upper-level program team leaders and stakeholders, the project leader, team members and stakeholders can access)';

$lang->project->authList['extend'] = 'Inherit (system privilege and project privilege)';
$lang->project->authList['reset']  = 'Reset (project privilege only)';

$lang->project->statusList['wait']      = 'Waiting';
$lang->project->statusList['doing']     = 'Doing';
$lang->project->statusList['suspended'] = 'Suspended';
$lang->project->statusList['closed']    = 'Closed';

$lang->project->endList[31]  = 'One month';
$lang->project->endList[93]  = 'Trimester';
$lang->project->endList[186] = 'Half yearly';
$lang->project->endList[365] = 'One year';
$lang->project->endList[999] = 'Longtime';

$lang->project->empty                  = 'No project.';
$lang->project->accessDenied           = 'Access denied!';
$lang->project->chooseProgramType      = 'Select the project management model';
$lang->project->nextStep               = 'Next step';
$lang->project->hoursUnit              = '%s hours';
$lang->project->membersUnit            = '%s men';
$lang->project->lastIteration          = "Recent {$lang->executionCommon}";
$lang->project->ongoingStage           = 'Ongoing stage';
$lang->project->scrum                  = 'Scrum';
$lang->project->waterfall              = 'CMMI';
$lang->project->waterfallTitle         = 'CMMI';
$lang->project->cannotCreateChild      = 'It is not empty, so you cannot add a child. You can add a parent for it, and then create a child.';
$lang->project->confirmDelete          = "Do you want to delete [%s]?";
$lang->project->emptyPM                = 'No manager';
$lang->project->cannotChangeToCat      = "It is not empty, so you cannot change it to a parent.";
$lang->project->cannotCancelCat        = "It has child projects, so you cannot unmark the parent.";
$lang->project->parentBeginEnd         = "Parent begin&end date: %s ~ %s";
$lang->project->childLongTime          = "If a child as long-term projects, the parent should be long-term too.";
$lang->project->readjustTime           = 'Change the project begin&end date.';
$lang->project->notAllowRemoveProducts = 'The story of this product is linked with the project. Unlink it before doing any action.';

$lang->project->programTitle['0']    = 'Hide';
$lang->project->programTitle['base'] = 'Base-level project only';
$lang->project->programTitle['end']  = 'End-level project only';

$lang->project->accessDenied      = 'Access denied to this project';
$lang->project->chooseProgramType = 'Select management type';
$lang->project->scrumTitle        = 'Agile Development Management';
$lang->project->cannotCreateChild = 'The project has contents, so you cannot add a child project. You can create a parent project for this one and then add a child project for the parent project.';
$lang->project->hasChildren       = 'This project has a child project, so it cannot be deleted.';
$lang->project->confirmDelete     = 'Do you want to delete this project?';
$lang->project->cannotChangeToCat = "The project has contents, so you cannot it to a parent project.";
$lang->project->cannotCancelCat   = "There are child projects of this project. You cannot cancel the parent project mark.";
$lang->project->parentBeginEnd    = "The begin and end date of the parent project: %s ~ %s";
$lang->project->parentBudget      = "The budget of the parent project: ";
$lang->project->beginLetterParent = "The begin date of the parent project: %s. It cannot be < the begin date of its parent project.";
$lang->project->endGreaterParent  = "The end date of the parent project: %s. It cannot be > the end date of its parent project.";
$lang->project->beginGreateChild  = "The minimum start date of the project set: %s. The start date of the project cannot be less than the minimum start date of the project set.";
$lang->project->endLetterChild    = "The maximum finish date for the project set: %s. The completion date of a project cannot be greater than the maximum completion date of the project set.";
$lang->project->childLongTime     = "There are long-term projects in the child project, and the parent project should also be a long-term project.";
